@@ -190,4 +190,17 @@ def kill(ctx, datasource):
     task_to_submit = tasks.KillTask(datasource)
     click.echo(
         json.dumps(api.post_task(task_to_submit), indent=INDENT)
-    )
\ No newline at end of file
+    )
+
+
+@submit.command(short_help="submit delete task",
+                help="Submit detele task that creates empty segment with no data")
+@click.pass_context
+@click.argument('datasource',)
+@explain_errors
+def delete(ctx, datasource):
+    api = ctx.obj['api']
+    task_to_submit = tasks.DeleteTask(datasource)
+    click.echo(
+        json.dumps(api.post_task(task_to_submit), indent=INDENT)
+    )
